@@ -10,7 +10,7 @@ from abc import ABC, abstractmethod
 from fastavro import schemaless_reader, schemaless_writer
 from jsonschema import validate
 
-from schema_registry.client import SchemaRegistryClient, schema, utils, AsyncSchemaRegistryClient
+from schema_registry.client import AsyncSchemaRegistryClient, SchemaRegistryClient, schema, utils
 from schema_registry.client.errors import ClientError
 from schema_registry.client.schema import BaseSchema
 
